#include <QFileInfo>
#include <QFileDialog>
#include <DlgClassProperties.hpp>

DlgClassProperties::DlgClassProperties(QString const& currentDoc,
									   QString const& subdir,
									   QWidget* parent)
:	QDialog(parent)
{
	ui.setupUi(this);

	ui.lineEditClassName->setText("NewClass");
	QFileInfo fi(currentDoc);
	if(fi.exists())
	{
		QString path = fi.canonicalPath();
		int sp = path.lastIndexOf(subdir, Qt::CaseInsensitive);
		if((0 < sp) &&
		   ((path.size() - subdir.size()) == sp) &&
		   (0 <= QString("/\\").indexOf(path.at(sp - 1))))
			path = path.left(sp - 1);
		ui.lineEditPath->setText(path);
	}

	ui.comboBoxAccessSpec->addItem("public");
	ui.comboBoxAccessSpec->addItem("protected");
	ui.comboBoxAccessSpec->addItem("private");
	ui.comboBoxAccessSpec->setCurrentIndex(0);

	connect(ui.lineEditParentClass, SIGNAL(textChanged(QString const&)),
			this, SLOT(setEnableAccessCombo(QString const&)));
	connect(ui.pushButtonBrowsePath, SIGNAL(released()),
			this, SLOT(browsePath()));
}

void DlgClassProperties::setEnableAccessCombo(QString const& text)
{
	ui.comboBoxAccessSpec->setEnabled(!text.isEmpty());
}

void DlgClassProperties::browsePath()
{
	QFileDialog* fdlg = new QFileDialog(this, QObject::tr("Select directory"),
										ui.lineEditPath->text());
	fdlg->setFileMode(QFileDialog::Directory);
	fdlg->setOption(QFileDialog::ShowDirsOnly);
	if(QDialog::Accepted == fdlg->exec())
		ui.lineEditPath->setText(fdlg->directory().canonicalPath());
}
