#include <QPlainTextDocumentLayout>
#include <TextModSettings.hpp>
#include <DlgCppSettings.hpp>

DlgCppSettings::DlgCppSettings(TextModSettings const& sett,
							   QWidget* parent)
:	QTabWidget(parent),
	docHppTemplate_(new QTextDocument(this)),
	docIncludeParent_(new QTextDocument(this)),
	docParentAccess_(new QTextDocument(this)),
	docCppTemplate_(new QTextDocument(this)),
	docConstructParent_(new QTextDocument(this))
{
	ui.setupUi(this);

    ui.lineEditHppExt->setText(sett.hppExt_);
	ui.lineEditHppSubdirectory->setText(sett.hppSubdirectory_);
    ui.lineEditCppExt->setText(sett.cppExt_);
	ui.lineEditCppSubdirectory->setText(sett.cppSubdirectory_);

	docHppTemplate_->setDocumentLayout(new QPlainTextDocumentLayout(docHppTemplate_));
	docHppTemplate_->setPlainText(sett.hppTemplate_);
	docIncludeParent_->setDocumentLayout(new QPlainTextDocumentLayout(docIncludeParent_));
	docIncludeParent_->setPlainText(sett.includeParent_);
	docParentAccess_->setDocumentLayout(new QPlainTextDocumentLayout(docParentAccess_));
	docParentAccess_->setPlainText(sett.parentAccess_);
	docCppTemplate_->setDocumentLayout(new QPlainTextDocumentLayout(docCppTemplate_));
	docCppTemplate_->setPlainText(sett.cppTemplate_);
	docConstructParent_->setDocumentLayout(new QPlainTextDocumentLayout(docConstructParent_));
	docConstructParent_->setPlainText(sett.constructParent_);

    ui.plainTextEditHppTemplate->setDocument(docHppTemplate_);
    ui.plainTextEditIncludeParent->setDocument(docIncludeParent_);
    ui.plainTextEditParentAccess->setDocument(docParentAccess_);
    ui.plainTextEditCppTemplate->setDocument(docCppTemplate_);
    ui.plainTextEditConstructParent->setDocument(docConstructParent_);
}

void DlgCppSettings::getSettings(TextModSettings& sett)
{
    sett.hppExt_ = trimLeading(".", ui.lineEditHppExt->text().trimmed());
	sett.hppSubdirectory_ = trimLeading("/\\", ui.lineEditHppSubdirectory->text().trimmed());
    sett.hppTemplate_ = ui.plainTextEditHppTemplate->toPlainText();
    sett.includeParent_ = ui.plainTextEditIncludeParent->toPlainText();
    sett.parentAccess_ = ui.plainTextEditParentAccess->toPlainText();
    sett.cppExt_ = trimLeading(".", ui.lineEditCppExt->text().trimmed());
	sett.cppSubdirectory_ = trimLeading("/\\", ui.lineEditCppSubdirectory->text().trimmed());
    sett.cppTemplate_ = ui.plainTextEditCppTemplate->toPlainText();
	sett.constructParent_ = ui.plainTextEditConstructParent->toPlainText();
}

QString DlgCppSettings::trimLeading(QString const& chars, QString const& str) const
{
	QString ncChars = chars;
	int p = str.indexOf(QRegExp(QString("[^%1]").arg(ncChars.replace("\\", "\\\\"))));
	if(0 > p)
		return str;
	return str.mid(p);
}
