// TextModSettings.cpp
//
// Created: 2011-01-03T08:30:30

#include <juffed/JuffPlugin.h>
#include <juffed/PluginSettings.h>
#include <TextModSettings.hpp>

TextModSettings::TextModSettings()
:	hppExt_("hpp"),
	hppSubdirectory_(""),
	hppTemplate_(
		"#ifndef __[CLASS]_[HPP_EXT]__\n"
		"#define __[CLASS]_[HPP_EXT]__\n"
		"\n"
		"// [class].[hpp_ext]\n"
		"//\n"
		"// Created: [date]\n"
		"[include_parent]\n"
		"class [class][parent_access]\n"
		"{\n"
		"public:\n"
		"\t[class]();\n"
		"\t~[class]();\n"
		"\n"
		"private:\n"
		"\n"
		"};\n"
		"\n"
		"#endif\n"),
	includeParent_(
		"\n#include \"[parent].[hpp_ext]\"\n"),
	parentAccess_(
		": [qualifier] [parent]"),
	cppExt_("cpp"),
	cppSubdirectory_(""),
	cppTemplate_(
		"// [class].[cpp_ext]\n"
		"//\n"
		"// Created: [date]\n"
		"\n"
		"#include <[class].[hpp_ext]>\n"
		"\n"
		"[class]::[class]()[construct_parent]\n"
		"{\n"
		"}\n"
		"\n"
		"[class]::~[class]()\n"
		"{\n"
		"}\n"),
	constructParent_(
		"\n:\t[parent]()")
{
}

void TextModSettings::load(JuffPlugin* jp)
{
	// test whether we are really having saved settings
	if(!PluginSettings::getBoolValue(jp, "hasSettings"))
		return;

	hppExt_ = PluginSettings::getStringValue(jp, "hppExt");
	hppSubdirectory_ = PluginSettings::getStringValue(jp, "hppSubdirectory");
	hppTemplate_ = PluginSettings::getStringValue(jp, "hppTemplate");
	includeParent_ = PluginSettings::getStringValue(jp, "includeParent");
	parentAccess_ = PluginSettings::getStringValue(jp, "parentAccess");
	cppExt_ = PluginSettings::getStringValue(jp, "cppExt");
	cppSubdirectory_ = PluginSettings::getStringValue(jp, "cppSubdirectory");
	cppTemplate_ = PluginSettings::getStringValue(jp, "cppTemplate");
	constructParent_ = PluginSettings::getStringValue(jp, "constructParent");
}

void TextModSettings::save(JuffPlugin* jp)
{
	PluginSettings::setBoolValue(jp, "hasSettings", true);
	PluginSettings::setStringValue(jp, "hppExt", hppExt_);
	PluginSettings::setStringValue(jp, "hppSubdirectory", hppSubdirectory_);
	PluginSettings::setStringValue(jp, "hppTemplate", hppTemplate_);
	PluginSettings::setStringValue(jp, "includeParent", includeParent_);
	PluginSettings::setStringValue(jp, "parentAccess", parentAccess_);
	PluginSettings::setStringValue(jp, "cppExt", cppExt_);
	PluginSettings::setStringValue(jp, "cppSubdirectory", cppSubdirectory_);
	PluginSettings::setStringValue(jp, "cppTemplate", cppTemplate_);
	PluginSettings::setStringValue(jp, "constructParent", constructParent_);
}
